@@ -1,7 +1,7 @@
 #!/bin/sh
 # usage: xprobe.sh driver
 # Copyright (C) 2004 Canonical Ltd.
-# Author: Daniel Stone <daniel.stone@canonical.com>
+# Author: Daniel Stone <daniel.stone@ubuntu.com>
 # 
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -28,28 +28,20 @@ if [ -z "$DRIVER" ]; then
   exit 1
 fi
 
-if [ "$DRIVER" = "i810" -a -z "$XRESPROBE_FORCE_PROBE" -a -z \
-     "$(find /tmp/.X11-unix -type s)" ]; then
-  if [ -n "$XRESPROBE_DEBUG" ]; then
-    echo "not starting X in probeonly mode with display already active on i8xx" >&2
-  fi
-  exit 1
-fi
-
 set -e
 if [ -z "$TMPDIR" ]; then
 	TMPDIR="/tmp"
 fi
 XDIR="$TMPDIR/xprobe.$$"
-TMPCONF="$XDIR/xfree86.conf"
-TMPLOG="$XDIR/xfree86.log"
-TMPOUT="$XDIR/xfree86-stdout.log"
+TMPCONF="$XDIR/xorg.conf"
+TMPLOG="$XDIR/xorg.log"
+TMPOUT="$XDIR/xorg-stdout.log"
 
 mkdir -m700 "$XDIR"
-sed -e "s/::DRIVER::/$DRIVER/;" < "$DATAPATH/xfree86.conf" > "$TMPCONF"
+sed -e "s/::DRIVER::/$DRIVER/;" < "$DATAPATH/xorg.conf" > "$TMPCONF"
 set +e
 
-/etc/X11/X :67 -ac -probeonly -logfile "$TMPLOG" -xf86config "$TMPCONF" > "$TMPOUT" 2>&1
+/etc/X11/X :67 -ac -probeonly -logfile "$TMPLOG" -config "$TMPCONF" > "$TMPOUT" 2>&1
 
 echo "$XDIR"
 exit 0
